@@ -266,7 +266,7 @@ bool fullscreen=false;
 		PsxCycleMult,
 		(enableAbbeyHack == false ? "OFF" : "ON"),
 		(iSoundMuted == 0 ? "ON" : "OFF"),
-		(fullscreen == 0 ? "ON" : "OFF")
+		(fullscreen == true ? "ON" : "OFF")
 	);
 #endif
 
